@@ -1,4 +1,4 @@
-/* $Id: libgdamm.h,v 1.2 2002/04/19 09:12:17 murrayc Exp $ */
+/* $Id: libgdamm.h 911 2007-01-13 19:32:27Z murrayc $ */
 /* libgdamm - a C++ wrapper for libgda
  *
  * Copyright 1999-2001 Free Software Foundation
@@ -30,11 +30,15 @@ extern const int libgdamm_major_version;
 extern const int libgdamm_minor_version;
 extern const int libgdamm_micro_version;
 
-#include <gtkmm.h>
+#include <glibmm.h>
 
 #include <libgdamm/init.h>
+#include <libgdamm/client.h>
+#include <libgdamm/config.h>
 #include <libgdamm/connection.h>
 #include <libgdamm/datamodel.h>
-#include <libgdamm/error.h>
+#include <libgdamm/connectionevent.h>
+#include <libgdamm/datamodelquery.h>
+#include <libgdamm/query.h>
 
 #endif /* #ifndef LIBGDAMM_H */
